# PinTableHeaderRowsRequest

Updates the number of pinned table header rows in a table.

**Type:** object

## Properties

- **tableStartLocation** ([Location](location.md)): The location where the table starts in the document.
- **pinnedHeaderRowsCount** (integer): The number of table rows to pin, where 0 implies that all rows are unpinned.
